Video Analysis {#tutorial_js_table_of_contents_video}
==============

-   @subpage tutorial_js_meanshift

    Here, we will learn about tracking algorithms such as "Meanshift", and its upgraded version, "Camshift"
    to find and track objects in videos.

-   @subpage tutorial_js_lucas_kanade

    Now let's discuss an important concept, "Optical Flow", which is related to videos and has many
    applications.

-   @subpage tutorial_js_bg_subtraction

    In several applications, we need to extract foreground for further operations like object tracking.
    Background Subtraction is a well-known method in those cases.
